#
# spec file for package ghc-yesod-core
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name yesod-core
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.6.25.1
Release:        bp156.1.1
Summary:        Creation of type-safe, RESTful web applications
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Patch1:         drop-dependency-on-empty-attoparsec-aeson-library.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-clientsession-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-extra-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-entropy-devel
BuildRequires:  ghc-fast-logger-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-path-pieces-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-shakespeare-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-extra-devel
BuildRequires:  ghc-wai-logger-devel
BuildRequires:  ghc-warp-devel
BuildRequires:  ghc-word8-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-expectations-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-streaming-commons-devel
%endif

%description
API docs and the README are available at
<http://www.stackage.org/package/yesod-core>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version} -p1

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Tue Nov 28 2023 Peter Simons <psimons@suse.com>
- Update yesod-core to version 1.6.25.1.
  [#]# 1.6.25.1
  * Export the options that were created in 1.6.25.0 [#1825](https://github.com/yesodweb/yesod/pull/1825)
  [#]# 1.6.25.0
  * Add an options structure that allows the user to set which instances will be derived for a routes structure. [#1819](https://github.com/yesodweb/yesod/pull/1819)
  [#]# 1.6.24.5
  * Support Aeson 2.2 [#1818](https://github.com/yesodweb/yesod/pull/1818)
  [#]# 1.6.24.4
  * Fix test-suite compilation error for GHC >= 9.0.1 [#1812](https://github.com/yesodweb/yesod/pull/1812)
  [#]# 1.6.24.3
  * Fix subsite-to-subsite dispatch [#1805](https://github.com/yesodweb/yesod/pull/1805)
  [#]# 1.6.24.2
  * No star is type [#1797](https://github.com/yesodweb/yesod/pull/1797)
  [#]# 1.6.24.1
  * Adapt to removal of `ListT` from transformers-0.6. [#1796](https://github.com/yesodweb/yesod/pull/1796)
  [#]# 1.6.24.0
  * Make catching exceptions configurable and set the default back to rethrowing async exceptions. [#1772](https://github.com/yesodweb/yesod/pull/1772).
  [#]# 1.6.23.1
  * Fix typo in creation of the description `<meta>` tag in `defaultLayout`. [#1766](https://github.com/yesodweb/yesod/pull/1766)
  [#]# 1.6.23
  * Add idempotent versions of `setDescription`, `setDescriptionI`. These functions
    have odd behaviour when called multiple times, so they are now warned against.
    This can't be a silent change - if you want to switch to the new functions, make
    sure your layouts are updated to use `pageDescription` as well as `pageTitle`.
    [#1765](https://github.com/yesodweb/yesod/pull/1765)
  [#]# 1.6.22.1
  + Remove sometimes failing superfluous test. [#1756](https://github.com/yesodweb/yesod/pull/1756)
  [#]# 1.6.22.0
  * Add missing list to documentation for ``Yesod.Core.Dispatch.warp``. [#1745](https://github.com/yesodweb/yesod/pull/1745)
  * Add instances for `ToContent Void`, `ToTypedContent Void`. [#1752](https://github.com/yesodweb/yesod/pull/1752)
  * Handle async exceptions within yesod rather then warp. [#1753](https://github.com/yesodweb/yesod/pull/1753)
  * Support template-haskell 2.18 [#1754](https://github.com/yesodweb/yesod/pull/1754)
* Fri Jul 23 2021 psimons@suse.com
- Update yesod-core to version 1.6.21.0.
  [#]# 1.6.21.0
  * Export `Yesod.Core.Dispatch.defaultGen` so that users may reuse it for their own `YesodRunnerEnv`s [#1734](https://github.com/yesodweb/yesod/pull/1734)
* Thu Jul  1 2021 psimons@suse.com
- Update yesod-core to version 1.6.20.2.
  [#]# 1.6.20.2
  * Fix compatibility with template-haskell 2.17 [#1729](https://github.com/yesodweb/yesod/pull/1729)
* Sat May 22 2021 psimons@suse.com
- Update yesod-core to version 1.6.20.1.
  [#]# 1.6.20.1
  * Throw an error in `breadcrumbs` if the trail of breadcrumbs is circular. [#1727](https://github.com/yesodweb/yesod/issues/1727)
* Tue May 11 2021 psimons@suse.com
- Update yesod-core to version 1.6.20.
  [#]# 1.6.20
  * Generate CSRF tokens using a secure entropy source [#1726](https://github.com/yesodweb/yesod/pull/1726)
  * Change semantics of `yreGen` and `defaultGen`
* Fri Apr  9 2021 psimons@suse.com
- Update yesod-core to version 1.6.19.0.
  [#]# 1.6.19.0
  * Change order of priority in `languages`[#1721](https://github.com/yesodweb/yesod/pull/1721)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Dec 14 2020 psimons@suse.com
- Update yesod-core to version 1.6.18.8.
  [#]# 1.6.18.8
  * Fix test suite for wai-extra change around vary header
* Thu Nov 19 2020 psimons@suse.com
- Update yesod-core to version 1.6.18.7.
  [#]# 1.6.18.7
  * Fix functions generating Open Graph metadata[#1709](https://github.com/yesodweb/yesod/pull/1709)
* Sun Nov  8 2020 psimons@suse.com
- Update yesod-core to version 1.6.18.6.
  [#]# 1.6.18.6
  * Update documentation from `HandlerT` to `HandlerFor` [#1703](https://github.com/yesodweb/yesod/pull/1703)
* Tue Oct 20 2020 psimons@suse.com
- Update yesod-core to version 1.6.18.5.
  [#]# 1.6.18.5
  Document `ErrorResponse` [#1698](https://github.com/yesodweb/yesod/pull/1698)
* Thu Sep 24 2020 psimons@suse.com
- Update yesod-core to version 1.6.18.4.
  [#]# 1.6.18.4
  * Fixed a bug where `mkYesod` and other TH functions didn't work for datatypes with explicitly stated type variables, including the case with typeclass constraints. [https://github.com/yesodweb/yesod/pull/1697](#1697)
  [#]# 1.6.18.3
  * Remove mention of an oudated Yesod type (`GHandler`) from the docs for `handlerToIO`. [https://github.com/yesodweb/yesod/pull/1695](#1695)
  [#]# 1.6.18.2
  * Recommends `.yesodroutes` as the file extension for Yesod routes files. [#1686](https://github.com/yesodweb/yesod/pull/1686)
  [#]# 1.6.18.1
  * Increase the size of CSRF token
* Mon Aug 31 2020 psimons@suse.com
- Update yesod-core to version 1.6.18 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add yesod-core at version 1.6.18.
